Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2953)

Unified Diff: chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h

Issue 769153007: Managed bookmarks for supervised users (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: string change Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h
diff --git a/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h b/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h
index 79b12507bfe37b0461e6e6705a75a54f4310a71b..fe2c19016275ae8636a713f76283021e29966d6e 100644
--- a/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h
+++ b/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h
@@ -232,6 +232,9 @@ willAnimateFromState:(BookmarkBar::State)oldState
// "Managed bookmarks" button on the left side, next to the apps button.
base::scoped_nsobject<BookmarkButton> managedBookmarksButton_;
+ // "Supervised bookmarks" button on the left side, next to the apps button.
+ base::scoped_nsobject<BookmarkButton> supervisedBookmarksButton_;
+
// "Other bookmarks" button on the right side.
base::scoped_nsobject<BookmarkButton> otherBookmarksButton_;
@@ -311,8 +314,8 @@ willAnimateFromState:(BookmarkBar::State)oldState
// Update the visible state of the bookmark bar.
- (void)updateVisibility;
-// Update the visible state of the extra butons on the bookmark bar: the
-// apps shortcut and the managed bookmarks folder.
+// Update the visible state of the extra buttons on the bookmark bar: the
+// apps shortcut and the managed and supervised bookmarks folders.
Alexei Svitkine (slow) 2015/01/23 16:06:13 Nit: replace the first "and" with a comma since th
Marc Treib 2015/01/26 12:27:42 Done.
- (void)updateExtraButtonsVisibility;
// Hides or shows the bookmark bar depending on the current state.

Powered by Google App Engine
This is Rietveld 408576698